@@ -19,7 +19,8 @@
  *                                                                         *
  *  You should have received a copy of the GNU General Public License      *
  *  along with this program; if not, write to the Free Software            *
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA*
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,             *
+ *  MA 02110-1301 USA                                                      *
  *                                                                         *
  ***************************************************************************/
 
@@ -47,11 +48,6 @@ void OnKoch()
     //read config from datafile ~/.aldorc
     libdatafile::Datafile fileconf(fileconf_name, libdatafile::Update);
 
-    libdatafile::sec_it main_sec = fileconf.section("Main");
-    string device = main_sec->option("Device")->getstr();
-    unsigned int samplerate = main_sec->option("SampleRate")->get();
-    unsigned int samplesize = main_sec->option("SampleSize")->get();
-
     libdatafile::sec_it keyer_sec = fileconf.section("Keyer");
     unsigned int beginpause = keyer_sec->option("BeginPause")->get();
     unsigned int charpause = keyer_sec->option("CharPause")->get();
@@ -67,7 +63,7 @@ void OnKoch()
     unsigned int skill = koch_sec->option("Skill")->get();
 
     Dialog<bool> ask_exit_koch(dlg_koch_title, main_menu_prompt);
-    ask_exit_koch.add_choice(dlg_koch_exit, false);
+    ask_exit_koch.add_default_choice(dlg_koch_exit, false);
     ask_exit_koch.add_choice(dlg_koch_continue, true);
 
     do
@@ -76,9 +72,10 @@ void OnKoch()
 	cout<<msg_speed<<startspeed<<" wpm"<<endl;
 	cout<<msg_start<<endl;
 
-	libaudiostream::oastream audio(device, samplerate, samplesize);
+	libaudiostream::AudioWorkSpace aws;
+
+	libkeyer::Keyer current_keyer(aws, startspeed, charpause, strpause, dotlen, linelen);
 
-	libkeyer::Keyer current_keyer(audio, startspeed, charpause, strpause, dotlen, linelen);
 	current_keyer.set_tone(tone);
 
 	libexercises::Classic current_classic(strnum, skill, strlen);
